@@ -1,6 +1,7 @@
 #!/usr/bin/env perl
 # Copyright (C) 2013-2015 Rocky Bernstein <rocky@cpan.org>
 # Documentation is at the __END__
+eval "use feature ':5.10';";
 use strict; use warnings;
 
 use rlib '..';
@@ -18,7 +19,7 @@ use Exporter;
 
 use constant PROGRAM => 'trepan.pl';
 use version;
-$VERSION='0.60'; # To fool CPAN indexer. Is <= real version
+$VERSION='0.70'; # To fool CPAN indexer. Is <= real version
 $VERSION = $Devel::Trepan::Version::VERSION;
 $PROGRAM = PROGRAM;
 
@@ -566,12 +567,6 @@ modules are present. If so, additional capabilies are available.
 
 =over 4
 
-=item *
-
-L<Devel::Callsite> allows you to see the exact location of where you
-are stopped. Location reporting changes by default to show the current
-OP address, when this module is present.
-
 =item *
 L<Enbugger> allows you to enter the debugger without previously having your program compiled for debugging.
 
@@ -631,7 +626,7 @@ GUI. The front end talks via a REST service.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2011, 2012, 2014 Rocky Bernstein <rocky@cpan.org>
+Copyright (C) 2011, 2012, 2014-2015 Rocky Bernstein <rocky@cpan.org>
 
 This program is distributed WITHOUT ANY WARRANTY, including but not
 limited to the implied warranties of merchantability or fitness for a
